@@ -1,5 +1,6 @@
 package MyPackage;
 use Moose;
+use MooseX::HasDefaults::RO;
 use lib '../lib';
 with 'DateTimeX::Mashup::Shiras';
 
@@ -17,4 +18,5 @@ print $firstinst->set_date_three( '11-September-2001' ) . "\n";
 print $firstinst->get_date_three_wkstart->dmy( '' ) . "\n";
 print $firstinst->set_date_one( -1299767400 ) . "\n";
 print $firstinst->set_date_one( 36764.54167 ) . "\n";
-print $firstinst->set_date_one( 0 ) . "\n";
\ No newline at end of file
+print $firstinst->set_date_one( 0 ) . "\n";
+print $firstinst->set_date_one( 60 ) . "\n";
\ No newline at end of file
